pub struct UrlHandlerApp {
pub appid: String,
pub name: String,
pub comment: Option<String>,
pub icon: IconSource,
pub path: PathBuf,
}Expand description
Represents an application that can handle specific URL schemes.
Fields
appid: Stringname: Stringcomment: Option<String>icon: IconSourcepath: PathBufImplementations
Sourceimpl UrlHandlerApp
impl UrlHandlerApp
Sourcepub fn handlers_for_scheme(
scheme: &str,
locales: Option<Vec<String>>,
search_paths: Option<Vec<PathBuf>>,
) -> Result<Vec<Self>>
pub fn handlers_for_scheme( scheme: &str, locales: Option<Vec<String>>, search_paths: Option<Vec<PathBuf>>, ) -> Result<Vec<Self>>
Retrieves all applications that can handle the specified URL scheme.
Arguments
scheme- The URL scheme to query (e.g., “http”, “mailto”).locales- Optional list of locales for localization. IfNone, it fetches the system’s default locales.search_paths- Optional list of paths to search for desktop entries. IfNone, it uses the default XDG paths.
Sourcepub fn from_desktop_entry<L: AsRef<str>>(
de: DesktopEntry,
locales: &[L],
) -> Self
pub fn from_desktop_entry<L: AsRef<str>>( de: DesktopEntry, locales: &[L], ) -> Self
Creates an [App] instance from a freedesktop_desktop_entry::DesktopEntry.
Arguments
de- The desktop entry to convert.locales- Used for localizing the app’s name and comment.
pub fn icon_path(&self, icon_size: u16) -> Option<PathBuf>